@@ -2,6 +2,13 @@ import pyutilib.workflow
 import os.path
 currdir = os.path.dirname(os.path.abspath(__file__))+os.sep
 
+import sys
+if sys.platform.startswith('win'):
+    INPUT = open('example7.txt','r')
+    for line in INPUT:
+        print line,
+    sys.exit(0)
+
 # @ex:
 class TaskH(pyutilib.workflow.Task):
 
