@@ -151,9 +151,9 @@ class Task(object):
 
     def set_options(self, args):
         """Use a list of command-line options to initialize this task."""
-        [self.options, args] = self.parser.parse_known_args(args)
+        [self.options, args] = self._parser.parse_known_args(args)
         tmp = {}
-        for action in self.parser._actions:
+        for action in self._parser._actions:
             try:
                 val = getattr(self.options, action.dest)
                 tmp[action.dest] = val
@@ -174,16 +174,29 @@ class Task(object):
         for key in options:
             self.inputs[key].set_value(options[key])
 
+    def set_arguments(self, parser=None):
+        if parser is None:
+            return
+        for arg in self._parser_arg:
+            args = arg[0]
+            kwargs = arg[1]
+            self._parser.add_argument(*args, **kwargs)
+
+    def add_argument(self, *args, **kwargs):
+        self._parser_arg.append([args,kwargs])
+        self._parser.add_argument(*args, **kwargs)
+
     def _create_parser(self, parser=None):
         """Create the OptionParser object and populated it with option groups."""
         if parser is None:
-            self.parser = argparse.ArgumentParser()
+            self._parser = argparse.ArgumentParser()
         else:
-            self.parser = parser
+            self._parser = parser
+        self._parser_arg = []
         self._parser_group = {}
         self._create_parser_groups()
         for key in self._parser_group:
-            self.parser.add_argument_group(self._parser_group[key])
+            self._parser.add_argument_group(self._parser_group[key])
 
     def _create_parser_groups(self):
         """This method is called by the _create_parser method to setup the
